@@ -16,7 +16,7 @@
  *
  *  You should have received a copy of the GNU Library General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -44,4 +44,25 @@ peas_debug_init (void)
                          debug_log_handler,
                          NULL);
     }
+  else
+    {
+      const gchar *g_messages_debug;
+
+      g_messages_debug = g_getenv ("G_MESSAGES_DEBUG");
+
+      if (g_messages_debug == NULL)
+        {
+          g_setenv ("G_MESSAGES_DEBUG", G_LOG_DOMAIN, TRUE);
+        }
+      else
+        {
+          gchar *new_g_messages_debug;
+
+          new_g_messages_debug = g_strconcat (g_messages_debug, " ",
+                                              G_LOG_DOMAIN, NULL);
+          g_setenv ("G_MESSAGES_DEBUG", new_g_messages_debug, TRUE);
+
+          g_free (new_g_messages_debug);
+        }
+    }
 }
