@@ -32,7 +32,8 @@
 #include "testing.h"
 
 void
-testing_init (void)
+testing_init (gint    *argc,
+              gchar ***argv)
 {
   GError *error = NULL;
   static gboolean initialized = FALSE;
@@ -40,6 +41,9 @@ testing_init (void)
   if (initialized)
     return;
 
+  gtk_test_init (argc, argv, NULL);
+
+  /* Must be after gtk_test_init() changes the log settings*/
   testing_util_init ();
 
   g_irepository_prepend_search_path (BUILDDIR "/libpeas-gtk");
@@ -55,11 +59,7 @@ testing_engine_new (void)
 {
   PeasEngine *engine;
 
-  testing_init ();
-
-  /* Must be after requiring typelibs */
   engine = testing_util_engine_new ();
-
   peas_engine_add_search_path (engine, BUILDDIR "/tests/libpeas-gtk/plugins",
                                        SRCDIR   "/tests/libpeas-gtk/plugins");
 
@@ -136,6 +136,7 @@ void
 testing_show_widget (gpointer widget)
 {
   GtkWidget *window;
+  GLogFunc orig_log_handler;
 
   g_assert (GTK_IS_WIDGET (widget));
 
@@ -160,5 +161,10 @@ testing_show_widget (gpointer widget)
                     G_CALLBACK (delete_event_cb),
                     widget);
 
+  /* Do not abort if a warning occurs while running the widget */
+  orig_log_handler = g_log_set_default_handler (g_log_default_handler, NULL);
+
   gtk_main ();
+
+  g_log_set_default_handler (orig_log_handler, NULL);
 }
