@@ -65,8 +65,7 @@ int
 main (int   argc,
       char *argv[])
 {
-  g_test_init (&argc, &argv, NULL);
-  g_type_init ();
+  testing_init (&argc, &argv);
 
   /* Only test the basics */
   testing_extension_basic ("c");
