@@ -46,9 +46,7 @@ int
 main (int   argc,
       char *argv[])
 {
-  g_test_init (&argc, &argv, NULL);
-
-  g_type_init ();
+  testing_init (&argc, &argv);
 
   testing_extension_all ("seed");
 
