@@ -180,9 +180,7 @@ int
 main (int    argc,
       char **argv)
 {
-  g_test_init (&argc, &argv, NULL);
-
-  g_type_init ();
+  testing_init (&argc, &argv);
 
 #define TEST(path, ftest) \
   g_test_add ("/plugin-info/" path, TestFixture, \
